matminer.featurizers.tests package — matminer 0.5.1 documentation

# matminer.featurizers.tests package

## Submodules

## matminer.featurizers.tests.test_bandstructure module

class `matminer.featurizers.tests.test_bandstructure.` `BandstructureFeaturesTest`(methodName='runTest')

  Bases: `pymatgen.util.testing.PymatgenTest`

  `setUp`()

    Hook method for setting up the test fixture before exercising it.

  `test_BandFeaturizer`()
  `test_BranchPointEnergy`()

## matminer.featurizers.tests.test_base module

## matminer.featurizers.tests.test_composition module

class `matminer.featurizers.tests.test_composition.` `CompositionFeaturesTest`(methodName='runTest')

  Bases: `pymatgen.util.testing.PymatgenTest`

  `setUp`()

    Hook method for setting up the test fixture before exercising it.

  `test_ape`()
  `test_atomic_orbitals`()
  `test_band_center`()
  `test_cation_properties`()
  `test_cohesive_energy`()
  `test_elec_affin`()
  `test_elem`()
  `test_elem_deml`()
  `test_elem_matminer`()
  `test_elem_matscholar_el`()
  `test_en_diff`()
  `test_fere_corr`()
  `test_fraction`()
  `test_ionic`()
  `test_miedema_all`()
  `test_miedema_ss`()
  `test_oxidation_states`()
  `test_stoich`()
  `test_tm_fraction`()
  `test_valence`()
  `test_yang`()

## matminer.featurizers.tests.test_conversions module

class `matminer.featurizers.tests.test_conversions.` `TestConversions`(methodName='runTest')

  Bases: `unittest.case.TestCase`

  `test_composition_to_oxidcomposition`()
  `test_conversion_multiindex`()
  `test_conversion_multiindex_dynamic`()
  `test_dict_to_object`()
  `test_json_to_object`()
  `test_str_to_composition`()
  `test_structure_to_composition`()
  `test_structure_to_oxidstructure`()
  `test_to_istructure`()

## matminer.featurizers.tests.test_dos module

class `matminer.featurizers.tests.test_dos.` `DOSFeaturesTest`(methodName='runTest')

  Bases: `pymatgen.util.testing.PymatgenTest`

  `setUp`()

    Hook method for setting up the test fixture before exercising it.

  `test_DOSFeaturizer`()
  `test_DopingFermi`()
  `test_Hybridization`()
  `test_SiteDOS`()

## matminer.featurizers.tests.test_function module

class `matminer.featurizers.tests.test_function.` `TestFunctionFeaturizer`(methodName='runTest')

  Bases: `unittest.case.TestCase`

  `setUp`()

    Hook method for setting up the test fixture before exercising it.

  `test_featurize`()
  `test_featurize_labels`()
  `test_helper_functions`()
  `test_multi_featurizer`()

## matminer.featurizers.tests.test_site module

class `matminer.featurizers.tests.test_site.` `FingerprintTests`(methodName='runTest')

  Bases: `pymatgen.util.testing.PymatgenTest`

  `setUp`()

    Hook method for setting up the test fixture before exercising it.

  `tearDown`()

    Hook method for deconstructing the test fixture after testing it.

  `test_AverageBondAngle`()
  `test_AverageBondLength`()
  `test_afs`()
  `test_bop`()
  `test_chemenv_site_fingerprint`()
  `test_chemicalSRO`()
  `test_cns`()
  `test_crystal_nn_fingerprint`()
  `test_crystal_site_fingerprint`()
  `test_dataframe`()
  `test_ewald_site`()
  `test_gaussiansymmfunc`()
  `test_grdf`()
  `test_local_prop_diff`()
  `test_off_center_cscl`()
  `test_op_site_fingerprint`()
  `test_simple_cubic`()

    Test with an easy structure

  `test_site_elem_prop`()
  `test_voronoifingerprint`()

## matminer.featurizers.tests.test_structure module

class `matminer.featurizers.tests.test_structure.` `StructureFeaturesTest`(methodName='runTest')

  Bases: `pymatgen.util.testing.PymatgenTest`

  `setUp`()

    Hook method for setting up the test fixture before exercising it.

  `test_bob`()
  `test_bondfractions`()
  `test_cgcnn_featurizer`()
  `test_composition_features`()
  `test_coulomb_matrix`()
  `test_density_features`()
  `test_dimensionality`()
  `test_ewald`()
  `test_global_symmetry`()
  `test_jarvisCFID`()
  `test_min_relative_distances`()
  `test_orbital_field_matrix`()
  `test_ordering_param`()
  `test_packing_efficiency`()
  `test_prdf`()
  `test_rdf_and_peaks`()
  `test_redf`()
  `test_sine_coulomb_matrix`()
  `test_sitestatsfingerprint`()
  `test_ward_prb_2017_efftcn`()

    Test the effective coordination number attributes of Ward 2017

  `test_ward_prb_2017_lpd`()

    Test the local property difference attributes from Ward 2017

  `test_ward_prb_2017_strhet`()
  `test_xrd_powderPattern`()

## Module contents